@@ -4,9 +4,6 @@ controls which squares how many times per ply/move in a Chess board
 """
 from .chess_util import ChessUtil
 from .chess_dask_cluster import ChessDaskCluster
-from .chess_image_generator import ChessImageGenerator
-
-import multiprocessing
 
 class ChessControlHeatmap:
     "Class to generate the control heatmap based on the input PGN files"
@@ -16,6 +13,3 @@ class ChessControlHeatmap:
         game_list = ChessUtil.get_games_from_pgn_files()
         dask_cluster = ChessDaskCluster()
         dask_cluster.analyse_games_in_cluster(game_list)
-        # print("Done calculating heatmap, now generting gifs")
-        # pool = multiprocessing.Pool()
-        # pool.map(ChessImageGenerator.create_gif, gamedata_list)
