@@ -17,9 +17,9 @@ class ChessImageGenerator:
         "Prepare the rows and columns for the graph"
         matplotlib.use('agg')
 
-        if game_data is None or not "white" in game_data:
+        if game_data is None or len(game_data["white"])==0:
             print("Doing nothing for this game")
-            return
+            return None
 
         gamedata_mapwhite = game_data["white"]
         gamedata_mapblack = game_data["black"]
