@@ -18,18 +18,17 @@ class ChessUtil:
 
     @staticmethod
     def generate_ply_info_list_for_game(game):
-        """Returns a dict which contains the list of tasks to
-        be run and the number of plies for the game."""
+        "Returns a dict which contains the list of tasks to be run"
         board = Board()
         ply_no = 0
         game_tasks = []
         for ply in game.mainline_moves():
             board.push(ply)
-            ply_info = {"ply_no": ply_no, "board": board}
+            ply_info = {"ply_no": ply_no, "board": board.copy()}
             game_tasks.append(ply_info)
             ply_no = ply_no + 1
 
-        return {"ply_info_list": game_tasks, "ply_count": ply_no}
+        return {"game_tasks": game_tasks, "ply_count": ply_no}
 
     @staticmethod
     def find_control_for_square_for_color(ply_info, color):
@@ -37,18 +36,17 @@ class ChessUtil:
         board = ply_info["board"]
         power_of_square_list = []
         ply_no = ply_info['ply_no']
-        colorKey = "black"
+        color_key = "black"
         if color:
-            colorKey = "white"
+            color_key = "white"
         for square in SQUARE_NAMES:
             parsed_square = parse_square(square)
             power_of_square_dict = {"ply": ply_no}
-            power_of_square_dict['square'] = parsed_square
-            
+            power_of_square_dict['square'] = parsed_square         
             new_board = board.copy()
             attackers = board.attackers(color, parsed_square)
             if len(attackers) == 0:
-                power_of_square_dict[colorKey] = 0
+                power_of_square_dict[color_key] = 0
                 power_of_square_list.append(power_of_square_dict)
 
             power_of_square = 0
@@ -65,7 +63,7 @@ class ChessUtil:
                 new_board.remove_piece_at(attacking_square)
                 power_of_square = power_of_square + 1
                 attackers = new_board.attackers(color, parsed_square)
-            power_of_square_dict[colorKey] = power_of_square
+            power_of_square_dict[color_key] = power_of_square
             power_of_square_list.append(power_of_square_dict)
         return power_of_square_list
 
